PURE_MODELS = (
    "UserCF",
    "ItemCF",
    "SVD",
    "SVDpp",
    "ALS",
    "NCF",
    "BPR",
    "DeepWalk",
    "NGCF",
    "LightGCN",
)

FEAT_MODELS = (
    "WideDeep",
    "FM",
    "DeepFM",
    "AutoInt",
    "PinSage",
    "PinSageDGL",
    "GraphSage",
    "GraphSageDGL",
)

SEQUENCE_MODELS = (
    "YouTubeRetrieval",
    "YouTubeRanking",
    "DIN",
    "Item2Vec",
    "RNN4Rec",
    "Caser",
    "WaveNet",
)

GRAPH_MODELS = (
    "DeepWalk",
    "NGCF",
    "LightGCN",
    "PinSage",
    "PinSageDGL",
    "GraphSage",
    "GraphSageDGL",
)

TF_FEAT_MODELS = (
    "WideDeep",
    "FM",
    "DeepFM",
    "YouTubeRanking",
    "AutoInt",
    "DIN",
)

EMBEDDING_MODELS = (
    "SVD",
    "SVDpp",
    "ALS",
    "BPR",
    "YouTubeRetrieval",
    "Item2Vec",
    "RNN4Rec",
    "Caser",
    "WaveNet",
    "DeepWalk",
    "NGCF",
    "LightGCN",
    "PinSage",
    "PinSageDGL",
    "GraphSage",
    "GraphSageDGL",
)
